==> pulumi-aws-kotlin-6.13.1.0-sources.jar: com/pulumi/aws/appflow/kotlin/inputs/FlowTriggerConfigTriggerPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appflow.kotlin.inputs

import com.pulumi.aws.appflow.inputs.FlowTriggerConfigTriggerPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property scheduled
 */
public data class FlowTriggerConfigTriggerPropertiesArgs(
    public val scheduled: Output<FlowTriggerConfigTriggerPropertiesScheduledArgs>? = null,
) : ConvertibleToJava<com.pulumi.aws.appflow.inputs.FlowTriggerConfigTriggerPropertiesArgs> {
    override fun toJava(): com.pulumi.aws.appflow.inputs.FlowTriggerConfigTriggerPropertiesArgs =
        com.pulumi.aws.appflow.inputs.FlowTriggerConfigTriggerPropertiesArgs.builder()
            .scheduled(scheduled?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [FlowTriggerConfigTriggerPropertiesArgs].
 */
@PulumiTagMarker
public class FlowTriggerConfigTriggerPropertiesArgsBuilder internal constructor() {
    private var scheduled: Output<FlowTriggerConfigTriggerPropertiesScheduledArgs>? = null

    /**
     * @param value
     */
    @JvmName("jvsxlpscrlfuaqbi")
    public suspend fun scheduled(`value`: Output<FlowTriggerConfigTriggerPropertiesScheduledArgs>) {
        this.scheduled = value
    }

    /**
     * @param value
     */
    @JvmName("knqndutiqctypuae")
    public suspend fun scheduled(`value`: FlowTriggerConfigTriggerPropertiesScheduledArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scheduled = mapped
    }

    /**
     * @param argument
     */
    @JvmName("qiuaixfipdgoxple")
    public suspend
    fun scheduled(argument: suspend FlowTriggerConfigTriggerPropertiesScheduledArgsBuilder.() -> Unit) {
        val toBeMapped = FlowTriggerConfigTriggerPropertiesScheduledArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.scheduled = mapped
    }

    internal fun build(): FlowTriggerConfigTriggerPropertiesArgs =
        FlowTriggerConfigTriggerPropertiesArgs(
            scheduled = scheduled,
        )
}

==> pulumi-aws-kotlin-6.49.1.0-sources.jar: com/pulumi/aws/appflow/kotlin/inputs/FlowTriggerConfigTriggerPropertiesArgs.kt <==
@file:Suppress("NAME_SHADOWING", "DEPRECATION")

package com.pulumi.aws.appflow.kotlin.inputs

import com.pulumi.aws.appflow.inputs.FlowTriggerConfigTriggerPropertiesArgs.builder
import com.pulumi.core.Output
import com.pulumi.core.Output.of
import com.pulumi.kotlin.ConvertibleToJava
import com.pulumi.kotlin.PulumiTagMarker
import com.pulumi.kotlin.applySuspend
import kotlin.Suppress
import kotlin.Unit
import kotlin.jvm.JvmName

/**
 *
 * @property scheduled
 */
public data class FlowTriggerConfigTriggerPropertiesArgs(
    public val scheduled: Output<FlowTriggerConfigTriggerPropertiesScheduledArgs>? = null,
) : ConvertibleToJava<com.pulumi.aws.appflow.inputs.FlowTriggerConfigTriggerPropertiesArgs> {
    override fun toJava(): com.pulumi.aws.appflow.inputs.FlowTriggerConfigTriggerPropertiesArgs =
        com.pulumi.aws.appflow.inputs.FlowTriggerConfigTriggerPropertiesArgs.builder()
            .scheduled(scheduled?.applyValue({ args0 -> args0.let({ args0 -> args0.toJava() }) })).build()
}

/**
 * Builder for [FlowTriggerConfigTriggerPropertiesArgs].
 */
@PulumiTagMarker
public class FlowTriggerConfigTriggerPropertiesArgsBuilder internal constructor() {
    private var scheduled: Output<FlowTriggerConfigTriggerPropertiesScheduledArgs>? = null

    /**
     * @param value
     */
    @JvmName("cojrvvmkmpjqpdqi")
    public suspend fun scheduled(`value`: Output<FlowTriggerConfigTriggerPropertiesScheduledArgs>) {
        this.scheduled = value
    }

    /**
     * @param value
     */
    @JvmName("avusxlxwbkrdjgyt")
    public suspend fun scheduled(`value`: FlowTriggerConfigTriggerPropertiesScheduledArgs?) {
        val toBeMapped = value
        val mapped = toBeMapped?.let({ args0 -> of(args0) })
        this.scheduled = mapped
    }

    /**
     * @param argument
     */
    @JvmName("wemmrgaxuujgcgfb")
    public suspend fun scheduled(argument: suspend FlowTriggerConfigTriggerPropertiesScheduledArgsBuilder.() -> Unit) {
        val toBeMapped = FlowTriggerConfigTriggerPropertiesScheduledArgsBuilder().applySuspend {
            argument()
        }.build()
        val mapped = of(toBeMapped)
        this.scheduled = mapped
    }

    internal fun build(): FlowTriggerConfigTriggerPropertiesArgs =
        FlowTriggerConfigTriggerPropertiesArgs(
            scheduled = scheduled,
        )
}
